@@ -56,7 +56,8 @@ def load_models(feature_types: list, model_directory: str) -> list:
 
 def deploy_at_res(filepath: str, all_models: list, matrix_width: int, res: int, working_directory: str,
                   normalization_type: str, stem: str, max_examples_in_ram: int, num_straw_workers: int,
-                  threshold: float, batch_size: int, chromosome_subset: list = None):
+                  threshold: float, batch_size: int, chromosome_subset: list = None,
+                  use_multithreading: bool = True):
     out_path = working_directory + "/" + stem
     loop_file = out_path + '_loops_' + str(res) + '.bedpe'
     domain_file = out_path + '_domains_' + str(res) + '.bedpe'
@@ -73,7 +74,8 @@ def deploy_at_res(filepath: str, all_models: list, matrix_width: int, res: int,
                  preprocess_method=preprocessing_method,
                  use_arithmetic_mean=False,
                  norm=normalization_type,
-                 num_output_channels=3, chromosome_subset=chromosome_subset)
+                 num_output_channels=3, chromosome_subset=chromosome_subset,
+                 use_multithreading=use_multithreading)
     return loop_file, domain_file, stripe_file, loop_domain_file
 
 
@@ -91,7 +93,7 @@ class DeployTridentFeatures:
     def __init__(self, filepath: str, all_models: list, resolution_strings: list,
                  stem: str, working_directory: str, normalization_type: str, threshold: float, matrix_width: int,
                  max_examples_in_ram: int, num_straw_workers: int, batch_size: int,
-                 chromosome_subset: list = None):
+                 chromosome_subset: list = None, use_single_threading: bool = False):
         resolutions = []
         for res_string in resolution_strings:
             resolutions.append(int(res_string))
@@ -108,7 +110,8 @@ class DeployTridentFeatures:
             loops, domains, stripes, loop_domains = deploy_at_res(filepath, all_models, matrix_width, res,
                                                                   working_directory, normalization_type, stem,
                                                                   max_examples_in_ram, num_straw_workers,
-                                                                  threshold, batch_size, chromosome_subset)
+                                                                  threshold, batch_size, chromosome_subset,
+                                                                  (not use_single_threading))
 
             runtime = time.time() - start_time
             print("Executed resolution {} in {} seconds".format(res, runtime))
