@@ -71,7 +71,6 @@ class DeploySpears:
             self.__prediction_list.append((prediction[k, :, :, :], section[k][1]))
 
     def run_model_predictions(self):
-        print('run models')
         num_done_counter = 0.0
         while not (self.__production_done.is_set() and self.get_num_data_points() == 0):
             section = self.__straw_data_list.get_amount_and_clear(self.__batch_size)
@@ -161,7 +160,6 @@ class DeploySpears:
         return matrices, num_total_slices
 
     def generate_bedpe_annotation(self):
-        print('generate')
         skip_counter = 0
         while not (self.__prediction_done.is_set() and self.get_num_predictions() == 0):
             section = self.__prediction_list.get_all_and_clear()
@@ -180,7 +178,6 @@ class DeploySpears:
             self.__nms_handlers[k].do_nms_and_print_to_file(self.__out_files[k])
 
     def get_all_data_slices(self):
-        print('slices')
         while self.get_num_coordinates() > 0:
             coordinates = self.__coords_list.get_amount_and_clear(1)[0]
             if coordinates is None:
